PullDownButton class

Displays a pull-down menu and animates button to lower opacity when pressed.

See also:

Inheritance
Annotations

Constructors

PullDownButton({Key? key, required PullDownMenuItemBuilder itemBuilder, required PullDownMenuButtonBuilder buttonBuilder, PullDownMenuCanceled? onCanceled, Offset offset = Offset.zero, PullDownMenuPosition position = PullDownMenuPosition.under, PullDownMenuItemsOrder itemsOrder = PullDownMenuItemsOrder.downwards, PullDownMenuRouteTheme? routeTheme, bool? applyOpacity, Widget? topWidget})
Creates a button that shows a pull-down menu.
const

Properties

applyOpacity → bool?
Whether to apply opacity on buttonBuilder as it is in iOS or not.
final
buttonBuilder → PullDownMenuButtonBuilder
Builder that provides BuildContext as well as showMenu function to pass to any custom button widget.
final
hashCode → int
The hash code for this object.
no setterinherited
itemBuilder → PullDownMenuItemBuilder
Called when the button is pressed to create the items to show in the menu.
final
itemsOrder → PullDownMenuItemsOrder
Whether the popup menu orders its items from itemBuilder in downwards or upwards way.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
offset → Offset
The offset is applied relative to the initial position set by the position.
final
onCanceled → PullDownMenuCanceled?
Called when the user dismisses the pull-down menu.
final
position → PullDownMenuPosition
Whether the popup menu is positioned above, over or under the popup menu button.
final
routeTheme → PullDownMenuRouteTheme?
Theme of route used to display pull-down menu launched from this PullDownButton.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topWidget → Widget?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<PullDownButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited