PullDownMenuDividerTheme class

Defines the visual properties of the dividers in pull-down menus.

Is used by PullDownMenuDivider and vertical dividers in PullDownMenuActionsRow.

All PullDownMenuDividerTheme properties are null by default. When null, the pull-down menu will use iOS 16 defaults specified in PullDownMenuDividerTheme.defaults.

Mixed-in types
Annotations

Constructors

PullDownMenuDividerTheme({Color? dividerColor, Color? largeDividerColor})
Creates the set of properties used to configure PullDownMenuDividerTheme.
const

Properties

dividerColor → Color?
The divider color of the pull-down menu divider PullDownMenuDivider.
final
hashCode → int
The hash code for this object.
no setteroverride
largeDividerColor → Color?
The large divider color of the pull-down menu divider PullDownMenuDivider.large.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Color? dividerColor, Color? largeDividerColor}) → PullDownMenuDividerTheme
Creates a copy of this object with the given fields replaced with the new values.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

lerp(PullDownMenuDividerTheme? a, PullDownMenuDividerTheme? b, double t) → PullDownMenuDividerTheme
Linearly interpolate between two themes.
of(BuildContext context) → PullDownMenuDividerTheme?
The PullDownButtonTheme.dividerTheme property of the ambient PullDownButtonTheme.