PullDownMenuItem class

An item in a cupertino style pull-down menu.

To show a pull-down menu and create a button that shows a pull-down menu use PullDownButton.buttonBuilder.

To show a checkmark next to pull-down menu item (an item with selection state), consider using PullDownMenuItem.selectable.

By default, a PullDownMenuItem is minimum of kMinInteractiveDimensionCupertino pixels height.

Inheritance
Implemented types
Annotations

Constructors

PullDownMenuItem({Key? key, required VoidCallback? onTap, PullDownMenuItemTapHandler tapHandler = defaultTapHandler, bool enabled = true, required String title, IconData? icon, PullDownMenuItemTheme? itemTheme, Color? iconColor, Widget? iconWidget, bool isDestructive = false})
Creates an item for a pull-down menu.
const
PullDownMenuItem.selectable({Key? key, required VoidCallback? onTap, PullDownMenuItemTapHandler tapHandler = defaultTapHandler, bool enabled = true, required String title, IconData? icon, PullDownMenuItemTheme? itemTheme, Color? iconColor, Widget? iconWidget, bool isDestructive = false, bool? selected = false})
Creates a selectable item for a pull-down menu.
const

Properties

enabled → bool
Whether the user is permitted to tap this item.
final
hashCode → int
The hash code for this object.
no setterinherited
icon → IconData?
Icon of this PullDownMenuItem.
final
iconColor → Color?
Color for this PullDownMenuItem's icon.
final
iconWidget → Widget?
Custom icon widget of this PullDownMenuItem.
final
isDestructive → bool
Whether this item represents destructive action;
final
itemTheme → PullDownMenuItemTheme?
Theme of this PullDownMenuItem.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onTap → VoidCallback?
The action this item represents.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected → bool?
Whether to display a checkmark next to the menu item.
final
tapHandler → PullDownMenuItemTapHandler
Handler that provides this item's BuildContext as well as onTap to resolve how onTap callback is used.
final
title → String
Title of this PullDownMenuItem.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

defaultTapHandler(BuildContext context, VoidCallback? onTap) → void
Default tap handler for PullDownMenuItem.
noPopTapHandler(BuildContext _, VoidCallback? onTap) → void
An additional, pre-made tap handler for PullDownMenuItem.