PullDownMenuItemTheme class

Defines the visual properties of the items in pull-down menus.

Is used by PullDownMenuItem, PullDownMenuItem.selectable.

All PullDownMenuItemTheme properties are null by default. When null, the pull-down menu will use iOS 16 defaults specified in PullDownMenuItemTheme.defaults.

Mixed-in types
Annotations

Constructors

PullDownMenuItemTheme({Color? destructiveColor, double? iconSize, IconData? checkmark, FontWeight? checkmarkWeight, double? checkmarkSize, TextStyle? textStyle, TextStyle? iconActionTextStyle, Color? onHoverColor, TextStyle? onHoverTextStyle})
Creates the set of properties used to configure PullDownMenuItemTheme.
const

Properties

checkmark → IconData?
The selection icon for selected PullDownMenuItem.selectables.
final
checkmarkSize → double?
The size of chevron icons of items in the pull-down menu.
final
checkmarkWeight → FontWeight?
The font weight of selection icon for selected PullDownMenuItem.selectables.
final
destructiveColor → Color?
The destructive color of items in the pull-down menu.
final
hashCode → int
The hash code for this object.
no setteroverride
iconActionTextStyle → TextStyle?
The text style of PullDownMenuItem items inside PullDownMenuActionsRow in the pull-down menu.
final
iconSize → double?
The size of trailing icons of items in the pull-down menu.
final
onHoverColor → Color?
The on hover color of PullDownMenuItem.
final
onHoverTextStyle → TextStyle?
The on hover text style of PullDownMenuItem.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle → TextStyle?
The text style of items in the pull-down menu.
final

Methods

copyWith({Color? destructiveColor, double? iconSize, IconData? checkmark, FontWeight? checkmarkWeight, double? checkmarkSize, TextStyle? textStyle, TextStyle? iconActionTextStyle, Color? onHoverColor, TextStyle? onHoverTextStyle}) → PullDownMenuItemTheme
Creates a copy of this object with the given fields replaced with the new values.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

lerp(PullDownMenuItemTheme? a, PullDownMenuItemTheme? b, double t) → PullDownMenuItemTheme
Linearly interpolate between two themes.
of(BuildContext context) → PullDownMenuItemTheme?
The PullDownButtonTheme.itemTheme property of the ambient PullDownButtonTheme.