PullDownMenuRouteTheme class

Defines the visual properties of the routes used to display pull-down menus.

All PullDownMenuRouteTheme properties are null by default. When null, the pull-down menu will use iOS 16 defaults specified in _PullDownMenuRouteThemeDefaults.

Mixed-in types
Annotations

Constructors

PullDownMenuRouteTheme({Color? backgroundColor, BorderRadius? borderRadius, BoxShadow? beginShadow, BoxShadow? endShadow, double? width, double? topWidgetWidth})
Creates the set of properties used to configure PullDownMenuRouteTheme.
const

Properties

backgroundColor → Color?
The background color of the pull-down menu.
final
beginShadow → BoxShadow?
The pull-down menu shadow at the moment of menu being opened.
final
borderRadius → BorderRadius?
The border radius of the pull-down menu.
final
endShadow → BoxShadow?
The pull-down menu shadow at the moment of menu being fully opened.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topWidgetWidth → double?
final
width → double?
The width of pull-down menu.
final

Methods

copyWith({Color? backgroundColor, BorderRadius? borderRadius, BoxShadow? beginShadow, BoxShadow? endShadow, double? width}) → PullDownMenuRouteTheme
Creates a copy of this object with the given fields replaced with the new values.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

lerp(PullDownMenuRouteTheme? a, PullDownMenuRouteTheme? b, double t) → PullDownMenuRouteTheme
Linearly interpolate between two themes.
of(BuildContext context) → PullDownMenuRouteTheme?
The PullDownButtonTheme.routeTheme property of the ambient PullDownButtonTheme.