PullDownMenuTitleTheme class

Defines the visual properties of the titles in pull-down menus.

Is used by PullDownMenuTitle.

All PullDownMenuTitleTheme properties are null by default. When null, the pull-down menu will use iOS 16 defaults specified in _PullDownMenuTitleDefaults.

Mixed-in types
Annotations

Constructors

PullDownMenuTitleTheme({TextStyle? style})
Creates the set of properties used to configure PullDownMenuTitleTheme.
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → TextStyle?
The text style of title in the pull-down menu.
final

Methods

copyWith({TextStyle? style}) → PullDownMenuTitleTheme
Creates a copy of this object with the given fields replaced with the new values.
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

lerp(PullDownMenuTitleTheme? a, PullDownMenuTitleTheme? b, double t) → PullDownMenuTitleTheme
Linearly interpolate between two themes.
of(BuildContext context) → PullDownMenuTitleTheme?
The PullDownButtonTheme.titleTheme property of the ambient PullDownButtonTheme.